@@ -3,4 +3,4 @@ from oarepo_model_builder.model_preprocessors import ModelPreprocessor
 class MultilingualModelPreprocessor(ModelPreprocessor):
     def transform(self, schema, settings):
         self.set(settings.python, 'multilingual-dumper-class',
-                 lambda: f'{settings.package}.services.multilingual_dumper.MultilingualDumper')
\ No newline at end of file
+                 lambda: f'{settings.python.record_records_package}.multilingual_dumper.MultilingualDumper')
\ No newline at end of file
